@@ -2,7 +2,7 @@ package MooX::CalcTime::Role;
 use Modern::Perl;
 use Moo::Role;
 
-our $VERSION = '0.0.2'; # VERSION
+our $VERSION = '0.0.3'; # VERSION
 # ABSTRACT: calculate total time that a program run
 
 
@@ -25,7 +25,11 @@ sub get_runtime_format {
   my $total_hour    = int ($total_minute / 60);
   my $hour          = $total_hour % 60;
   my $day           = int($total_hour / 24);
-  my $msg = "Running time: $day days $hour hours $minute minutes $second second\n";
+  my $start = DateTime->from_epoch(epoch => $_[0]->_time_start);
+  my $end   = DateTime->now;
+  my $msg   = "Starting time: $start\n";
+  $msg .= "Ending time: $end\n";
+  $msg .= "Running time: $day days $hour hours $minute minutes $second second\n";
   return $msg;
 }
 
@@ -49,7 +53,7 @@ MooX::CalcTime::Role - calculate total time that a program run
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
